$(function() {
    $.bez('your_easing', [.17, .67, .21, 1]);

    var $slide_link = $('#slide-link');
    var $links = $slide_link.find('a');

    var $link1 = $links.first(),
        $link2 = $links.last();
    var link1_href = $link1[0].href,
        link2_href = $link2[0].href;
    var link1_width = $link1.width(),
        link2_width = $link2.width(),
        outer_width = $slide_link.width();
    var HEIGHT = 280; // in our case the stroke’s height was 280px
    var RATIO = 0.324919696233; // tangens(18°)
    var HALF_STROKE_WIDTH = RATIO * HEIGHT / 2;
    var x_state = {};

    var $svg = $('<svg class="clip-svg" width="' + outer_width + '" height="' + HEIGHT + '">' +
                 '    <defs>' +
                 '        <mask id="clip-slide-link1">' +
                 '            <polygon fill="white" points="0 0, ' + (outer_width + HALF_STROKE_WIDTH) + ' 0, ' + (outer_width - HALF_STROKE_WIDTH) + ' ' + HEIGHT +', 0 ' + HEIGHT + '" />' +
                 '        </mask>' +
                 '        <mask id="clip-slide-link2">' +
                 '            <polygon fill="white" points="' + HALF_STROKE_WIDTH + ' 0, ' + outer_width + ' 0, ' + outer_width + ' ' + HEIGHT + ', ' + (-HALF_STROKE_WIDTH) + ' ' + HEIGHT + '" />' +
                 '        </mask>' +
                 '    </defs>' +
                 '    <g mask="url(#clip-slide-link1)">' +
                 '        <text id="slide-link-text1" x="50%" y="50%" class="slide-link-text"></text>' +
                 '    </g>' +
                 '    <g mask="url(#clip-slide-link2)">' +
                 '        <text id="slide-link-text2" x="50%" y="50%" class="slide-link-text"></text>' +
                 '    </g>' +
                 '    <path id="stroke" fill="#ababab" d="M-44.023,277.106l-0.951-0.309L44.023,2.894l0.951,0.309L-44.023,277.106z">' +
                 '</svg>');
    var svg = $svg[0],
        mask1 = $svg.find('#clip-slide-link1').find('polygon')[0],
        mask2 = $svg.find('#clip-slide-link2').find('polygon')[0],
        text1 = $svg.find('#slide-link-text1')[0],
        text2 = $svg.find('#slide-link-text2')[0],
        stroke = $svg.find('#stroke')[0];

    var init = function() {
        text1.textContent = $link1.text();
        text2.textContent = $link2.text();
        x_state.start = (outer_width - Math.max(link1_width, link2_width)) / 2;
        x_state.end = (Math.max(link1_width, link2_width) + x_state.start);
        x_state.middle = x_state.start + (link1_width / 2 + link2_width / 2) / 2;
        $slide_link.width(outer_width);
        $slide_link.height(HEIGHT);
        $link1.detach();
        $link2.detach();
        $slide_link.append($svg);
    };
    init();

    function render(t) {
        var at = Math.abs(t);
        var x1, x2, x;

        x1 = x_state.middle;
        x2 = t < 0 ? x_state.start : x_state.end;
        x = x1 * (1 - at) + x2 * at;
        mask1.setAttribute('transform', 'matrix(1 0 0 1 ' + (x - outer_width) + ' 0)');
        mask2.setAttribute('transform', 'matrix(1 0 0 1 ' + x + ' 0)');
        stroke.setAttribute('transform', 'matrix(1 0 0 1 ' + x + ' 0)');

        x1 = 1;
        x2 = t > 0 ? 1 : 0.2;
        x = x1 * (1 - at) + x2 * at;
        text1.style.opacity = x;

        x1 = 1;
        x2 = t < 0 ? 1 : 0.2;
        x = x1 * (1 - at) + x2 * at;
        text2.style.opacity = x;
    }

    var $animation = $({t: 0});
    function animateTo(destination) {
        var t = destination == 'start' ? -1 : destination == 'end' ? 1 : 0;
        $animation.stop().animate({t: t}, {
            duration: 600,
            step: render,
            easing: 'your_easing'
        });
    }

    var lastPos = "middle";
    var currentHref = link1_href;
    $slide_link.on('mousemove', function(e) {
        var currentPos = "";
        if (e.pageX < $(window).width()/2) {
            currentPos = "end";
            currentHref = link1_href;
        } else {
            currentPos = "start";
            currentHref = link2_href;
        }
        if (lastPos === currentPos)
            return;
        animateTo(currentPos);
    }).on('mouseleave', function(e) {
        animateTo("middle");
    }).on('click', function() {
        window.location = currentHref;
    });

    render(0);
});
